package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.BERSequence;
import cn.com.infosec.asn1.BERTaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import java.util.Enumeration;

public class ContentInfo extends ASN1Encodable implements CMSObjectIdentifiers {
   private DERObjectIdentifier contentType;
   private DEREncodable content;

   public static ContentInfo getInstance(Object obj) {
      if (obj instanceof ContentInfo) {
         return (ContentInfo)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new ContentInfo((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public ContentInfo(ASN1Sequence seq) {
      Enumeration seq1;
      this.contentType = (DERObjectIdentifier)(seq1 = seq.getObjects()).nextElement();
      if (seq1.hasMoreElements()) {
         this.content = ((ASN1TaggedObject)seq1.nextElement()).getObject();
      }

   }

   public ContentInfo(DERObjectIdentifier contentType, DEREncodable content) {
      this.contentType = contentType;
      this.content = content;
   }

   public DERObjectIdentifier getContentType() {
      return this.contentType;
   }

   public DEREncodable getContent() {
      return this.content;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.contentType);
      DEREncodable var3;
      if ((var3 = this.content) != null) {
         BERTaggedObject var2;
         var2 = new BERTaggedObject.<init>(0, var3);
         var1.add(var2);
      }

      return new BERSequence(var1);
   }
}
